@@ -49,6 +49,8 @@
 
 int Debug=0;
 
+
+
 #ifdef __linux__
 #define LINUX 1
 #endif
@@ -79,9 +81,15 @@ CommandEntry Commands[] = {
  { NULL, "Uptime", "U",    
  	"Amount of elapsed time since system started", "T uptime | sed 's/,  load.*$//'",
 		"textStreamViewer -tSystem_Uptime -r1 -c40" },
+#ifdef SOLARIS_8
+ { NULL, "Vendor", "V",    
+ 	"Vendor of the OS", "P cat /etc/release",
+		"textStreamViewer -tOS_Vendor -r5 -c80" },
+#else
  { NULL, "Vendor", "V",    
  	"Vendor of the OS", "T cat /etc/issue | sed -n -e '2p'",
 		"textStreamViewer -tOS_Vendor -r1 -c60" },
+#endif
 #ifdef LINUX
  { NULL, "SysCtl", "",    
  	"Show Run Time settable Kernel Variables", "P /sbin/sysctl -a",
@@ -90,11 +98,19 @@ CommandEntry Commands[] = {
  	"Show the lilo config File", "P cat /etc/lilo.conf",
 		"textStreamViewer -t/etc/lilo.conf -r20 -c80" },
 #else
+
+#ifdef SOLARIS_8
+ { NULL, "Boot", "",    
+ 	"Show the boot config file, env", 
+	"P cat /boot/solaris.map ; cat /boot/solaris/bootenv.rc",
+		"textStreamViewer -tBoot_info -r20 -c80" },
+#else
  { NULL, "Boot", "",    
  	"Show the boot config file", "P cat /stand/boot",
 		"textStreamViewer -t/stand/boot -r20 -c80" },
- { NULL, "sysdef", "Display System parameters",    
- 	"", "P /usr/sbin/sysdef ",
+#endif
+ { NULL, "sysdef", "", "Display System parameters",    
+ 	 "P /usr/sbin/sysdef ",
 		"textStreamViewer -tsysdef -r40 -c80" },
  { NULL, "PkgInfo", "",    
  	"Show list of installed Packages", "P pkginfo",
@@ -102,10 +118,15 @@ CommandEntry Commands[] = {
  { NULL, "lp", "",    
  	"Produce printer status report", "P lpstat -s",
 		"textStreamViewer -tlpstat -r20 -c80" },
+#ifdef SOLARIS_8
+ { NULL, "sar", "",    
+ 	"Produce sys activity report", "P /usr/sbin/sar",
+		"textStreamViewer -tsar -r40 -c80" },
+#else
  { NULL, "sar", "",    
  	"Produce sys activity report", "P sar",
 		"textStreamViewer -tsar -r40 -c80" },
-
+#endif
 #endif
  { "", "Inittab",   "",    
  	"System initialization table", "P cat /etc/inittab", 
@@ -126,11 +147,17 @@ CommandEntry Commands[] = {
 		"textStreamViewer -t/proc/dma -r5 -c30" },
  { NULL, "interrupts", "",    "/proc/interrupts", "P cat /proc/interrupts",
 		"textStreamViewer -t/proc/interrupts -r16 -c50" },
+#else
+#ifdef SOLARIS_8
+ { NULL, "syslog", "",    
+ 	"Print important system messages", "P tail -300 /var/adm/messages",
+		"textStreamViewer -tSystem_Messeges -r40 -c120" },
 #else
  { NULL, "syslog", "",    
  	"Print important system messages", "P tail -300 /var/adm/syslog",
 		"textStreamViewer -tSystem_Messeges -r40 -c120" },
 #endif
+#endif
 #ifdef LINUX
  { "Misc", "CPU Info",  "C",    
  	"Display CPU information", "P cat /proc/cpuinfo",
@@ -171,8 +198,13 @@ CommandEntry Commands[] = {
 		"textStreamViewer -tSharedMemory_Pid -r25 -c80" },
  { NULL, "Creator",  "",    "ipcs -c", "P ipcs -c",
 		"textStreamViewer -tSharedMemory_Creator -r25 -c80" },
+#ifdef SOLARIS_8
+ { NULL, "Limits",  "",    "ipcs -l", "P ipcs -b",
+		"textStreamViewer -tSharedMemory_Limits -r25 -c80" },
+#else
  { NULL, "Limits",  "",    "ipcs -l", "P ipcs -l",
 		"textStreamViewer -tSharedMemory_Limits -r25 -c80" },
+#endif
  { NULL, "Sum",  "",    "ipcs -s", "P ipcs -s",
 		"textStreamViewer -tSharedMemory_Summary -r25 -c80" },
 #ifdef LINUX
@@ -229,10 +261,16 @@ CommandEntry Commands[] = {
 		"textStreamViewer -tMy_Processes -r40 -c80" },
  { NULL, "Run Levels",   "",  "Display run levels for system processes", "P /sbin/chkconfig --list",
 		"textStreamViewer -tRun_Levels -r40 -c80" },
+#else
+#ifdef SOLARIS_8
+ { NULL, "Mine",   "a",    
+ 	"display my processes", "P ps -al",
+		"textStreamViewer -tMy_Processes -r40 -c140" },
 #else
  { NULL, "Mine",   "a",    
  	"display my processes", "P ps -u 102 -f",
 		"textStreamViewer -tMy_Processes -r40 -c140" },
+#endif
  { NULL, "SAR: Buffer", "",    
  	"Produce sys activity report", "P sar -b",
 		"textStreamViewer -tSarBuffer -r40 -c80" },
@@ -288,7 +326,7 @@ CommandEntry Commands[] = {
  { NULL,      "Interfaces",  "", "Display network interface info", "P netstat -i", 
  		"textStreamViewer -tNetwork_Interfaces -r18 -c83"},
  { NULL,      "Routes",  "", "Display network routing info", "P netstat -r", 
- 		"textStreamViewer -tRouting_Info -r6 -c83"},
+ 		"textStreamViewer -tRouting_Info -r9 -c83"},
 #ifdef LINUX
  { NULL,      "Status",  "", "Display interface status", "P /sbin/ifconfig", 
  		"textStreamViewer -tNetwork_Interface_Info -r18 -c83"},
@@ -380,6 +418,7 @@ Widget Top_level, MainFormFW;
 
 char *Title="System Information App Launcher";
 
+
 Widget w;
 main(argc, argv)
 int argc;
@@ -389,7 +428,8 @@ char *argv[];
 	int 		 rc, n;
 	Arg 		 wargs[16];
 	char		 *title_str;
-	char		 *Config_file=NULL;
+	char		 *Panel_file=NULL;
+	char             buf[4096];
 
 	setvbuf( stderr, NULL, _IOLBF, 0 );  /* Unbuffered output */
 	setvbuf( stdout, NULL, _IOLBF, 0 );
@@ -417,7 +457,7 @@ char *argv[];
 	App_Trans_table = XtParseTranslationTable( appWidgetTranslations );
 
 	Debug = AppData.debug_level;   /* Set the debug packages debug level */
-	Config_file = AppData.config_file;
+	Panel_file = AppData.config_file;
 
 	/* Create a form to hold the menu and scrolled window  */
 
@@ -425,18 +465,7 @@ char *argv[];
 							Top_level, NULL, 0 );
 	parent    = MainFormFW;
 
-	/* Use a config file to determine what launcher definition file to use
-	 * if none found then use this builtin set.
-	 */
-
-	if ( strcmp( Config_file, "DEFAULT" ) != 0 )
-	{
-		/* go ahead! implement it!!!!*/
-		printf("loading from file not implemented yet\n"); 
-		exit(0);
-	}
-	else
-		createDefaultLaunchPad( parent );
+	createDefaultLaunchPad( parent );
 
 	XtAugmentTranslations( MainFormFW, App_Trans_table );
 
@@ -448,7 +477,6 @@ char *argv[];
 	XtAppMainLoop( MainContext );
 }
 
-
 createDefaultLaunchPad( parent )
 Widget parent;
 {
@@ -613,9 +641,9 @@ caddr_t call_data;
     if ( ( cmd[0] == 'P' ) || ( cmd[0] == 'T' ))  /* Execute and pipe to our own viewer */
     {
         if ( p->viewer ) /* override default viewer */
-           sprintf( command, "sh -c \"%s | %s &\" ", &(cmd[2]), p->viewer );
+           sprintf( command, "sh -c \"%s 2>&1 | %s &\" ", &(cmd[2]), p->viewer );
 	else
-           sprintf( command, "sh -c \"%s | textStreamViewer -t%s&\" ", &(cmd[2]), p->label );
+           sprintf( command, "sh -c \"%s 2>&1 | textStreamViewer -t%s&\" ", &(cmd[2]), p->label );
 
 
     	spawnExternal( command );
